# -*- coding: UTF-8 -*-
"""
@project: djangoModel->service
@author: 孙楷炎
@Email: sky4834@163.com
@synopsis:
@created_time: 2022/6/6 14:23
"""

from django.core.cache import cache

# import datetime
from .. import models
# from django.conf import settings
# from django.utils import timezone
# from django.core.cache import cache
from ..utils.model_handle import *


# def getConfigRouter():
# 	domain = router.getSiteDomain()
# 	return settings.DATABASE_MAPPING.get(domain, domain)
# # end - getConfigRouter


# cache 不支持异步
def getConfig(group=None, key=None):
    ch = cache.get('dictionary_configure')
    if not ch:
        ch = updateConfig()
    if not group:
        return ch
    if group in ch:
        if not key:
            return ch[group]
        if key in ch[group]:
            return ch[group][key]
    # end if

    return None


# end - getConfig


def updateConfig(group=None, key=None, value=None):
    ch = (cache.get('dictionary_configure') or {}) if group else {}
    if not ch or not group:
        for kv in models.Configure.objects.all():
            if str(kv.group) not in ch:
                ch[str(kv.group)] = {}
            ch[str(kv.group)][str(kv.key)] = str(kv.value)
        # end for
    elif group and key and value:
        if str(group) not in ch:
            ch[str(group)] = {}

        ch[str(group)][str(key)] = str(value)
    elif group and key:
        if str(group) not in ch:
            ch[str(group)] = {}

        try:
            ch[str(group)][str(key)] = str(models.Configure.objects.get(group=group, key=key).value)
        except:
            pass
        # end try
    elif group:
        if str(group) not in ch:
            ch[str(group)] = {}

        for kv in models.Configure.objects.filter(group=group):
            ch[str(group)][str(kv.key)] = str(kv.value)
        # end for
    # end if

    # cache.set("Config_{}".format(getConfigRouter()), ch)
    return ch


# end - updateConfig


def getPricing(province, hurry, key="邮费"):
    priceBase = None
    if province:
        priceBase = getConfig(key, province)
    if not priceBase and province:
        priceBase = getConfig(key, "其他省份")
    if not priceBase:
        priceBase = "0.0"

    price = float(priceBase)

    if hurry:
        priceHurry = getConfig(key, "当日加急")
        if priceHurry:
            price += float(priceHurry)
    # end if

    return price


# end - getPricing


# 创建配置
def setConfig(group, key, value, description):
    models.Configure.objects.update_or_create(
        group=group, key=key,
        defaults={"value": value, "description": description}
    )

    updateConfig()


# end - setConfig


# 配置删除
def delConfig(request):
    key = request.data.get('key', None)
    group = request.data.get('group', None)
    if not group or not key:
        return util_response(err=4055, msg="参数错误")
    res = models.Configure.objects.filter(group=group, key=key)
    if res:
        res.delete()
        return util_response()
    else:
        return util_response(err=2254, msg="该配置不存在")

# def getAdvert():
# 	return cache.get("Advert_{}".format(getConfigRouter())) or updateAdvert()
# #end - getAdvert
#
# def updateAdvert():
# 	data = {}
# 	for ad in models.Advert.objects.filter(expire__gte=timezone.now()).order_by("-sort"):
# 		if ad.location not in data:
# 			data[ad.location] = []
# 		data[ad.location].append({ "url" : ad.url, "img" : "{}{}".format(settings.MEDIA_URL, ad.image), "hint" : ad.hint })
# 	#end for
#
# 	cache.set("Advert_{}".format(getConfigRouter()), data)
# 	return data
# #end - updateAdvert



"""
Created on 2022-01-17
@author:刘飞
@description:自定义返回格式
"""
import json

from django.http import JsonResponse
from rest_framework import status


# json 结果集返回
def parse_json(result):
    if not result is None:
        if type(result) is str:
            try:
                result = json.loads(result.replace("'", '"').replace('\\r', "").replace('\\n', "").replace('\\t', "").replace('\\t', ""))
            except Exception as e:
                return result

        if type(result) is list:
            for index, value in enumerate(result):
                result[index] = parse_json(value)

        if type(result) is dict:
            for k, v in result.items():
                if type(v) is str:
                    try:
                        v = v.replace("'", '"').replace('\\r', "").replace('\\n', "").replace('\\t', "").replace('\\t', "")
                        result[k] = json.loads(v)
                    except Exception as e:
                        result[k] = v
                elif type(v) is dict:
                    result[k] = parse_json(v)
                else:
                    result[k] = v
    return result


# 数据返回规则
def util_response(data='', err=0, http_status=status.HTTP_200_OK, msg='ok'):
    if type(data) is list:
        if len(data) == 1:
            data = data[0]
    if http_status == status.HTTP_200_OK:
        return JsonResponse({'err': err, 'msg': msg, 'data': parse_json(data), })
    else:
        return JsonResponse({'err': http_status, 'msg': msg, }, status=http_status)


# 自定义错误页面时返回【DEBUG为True时生效】
def bad_request(request, exception):
    data = {'err': status.HTTP_400_BAD_REQUEST, 'msg': '参数错误', 'data': None}
    return JsonResponse(data=data, status=status.HTTP_400_BAD_REQUEST)


def permission_denied(request, exception):
    data = {'err': status.HTTP_403_FORBIDDEN, 'msg': '无权限', 'data': None}
    return JsonResponse(data=data, status=status.HTTP_403_FORBIDDEN)


def page_not_found(request, exception):
    data = {'err': status.HTTP_404_NOT_FOUND, 'msg': '资源不存在', 'data': None}
    return JsonResponse(data=data, status=status.HTTP_404_NOT_FOUND)


def page_error(exception):
    data = {'err': status.HTTP_500_INTERNAL_SERVER_ERROR, 'msg': '服务器错误', 'data': None}
    return JsonResponse(data=data, status=status.HTTP_500_INTERNAL_SERVER_ERROR)



# encoding: utf-8
"""
@project: djangoModel->url
@author: 孙楷炎
@Email: sky4834@163.com
@synopsis:
@created_time: 2022/6/6 14:25
"""

from django.urls import re_path

from .apis.dictionary_configure import DictionaryConfigure, DictionaryConfigurePage, BatchDictionaryConfigure

# from apps.dictionary.apis.dictionary_configure import DictionaryConfigure

# 应用名称
app_name = 'xj_dictionary'

urlpatterns = [
    re_path("^configure/?$", DictionaryConfigure.as_view()),
    re_path("^list/?$", DictionaryConfigurePage.as_view()),  # 分页展示配置
    re_path("^groups/?$", BatchDictionaryConfigure.as_view()),  # 分组配置获取

    # path("_configure/<str:group>", DictionaryConfigure.as_view()),
    # path("_configure/<str:group>/<str:key>", DictionaryConfigure.as_view()),
]
